summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrTextObject.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
commitafbfdc507bfaafc8824a9808311d57a9ece87510 (patch)
tree47be45bbd69c321ce79e14b683e59318748be9cb /kpresenter/KPrTextObject.cpp
parent880d042b2902fae8007f202dd35ad9330499867b (diff)
downloadkoffice-afbfdc507bfaafc8824a9808311d57a9ece87510.tar.gz
koffice-afbfdc507bfaafc8824a9808311d57a9ece87510.zip
Rename incorrect instances of tqrepaint[...] to repaint[...]
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240369 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrTextObject.cpp')
-rw-r--r--kpresenter/KPrTextObject.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpresenter/KPrTextObject.cpp b/kpresenter/KPrTextObject.cpp
index 90b3c66f..4d1a94c4 100644
--- a/kpresenter/KPrTextObject.cpp
+++ b/kpresenter/KPrTextObject.cpp
@@ -136,11 +136,11 @@ KPrTextObject::KPrTextObject( KPrDocument *doc )
TQT_SLOT( slotNewCommand( KCommand * ) ) );
connect( m_textobj, TQT_SIGNAL( availableHeightNeeded() ),
TQT_SLOT( slotAvailableHeightNeeded() ) );
- connect( m_textobj, TQT_SIGNAL( tqrepaintChanged( KoTextObject* ) ),
+ connect( m_textobj, TQT_SIGNAL( repaintChanged( KoTextObject* ) ),
TQT_SLOT( slotRepaintChanged() ) );
- // Send our "tqrepaintChanged" signals to the document.
- connect( this, TQT_SIGNAL( tqrepaintChanged( KPrTextObject * ) ),
+ // Send our "repaintChanged" signals to the document.
+ connect( this, TQT_SIGNAL( repaintChanged( KPrTextObject * ) ),
m_doc, TQT_SLOT( slotRepaintChanged( KPrTextObject * ) ) );
connect(m_textobj, TQT_SIGNAL( showFormatObject(const KoTextFormat &) ),
TQT_SLOT( slotFormatChanged(const KoTextFormat &)) );
@@ -1296,7 +1296,7 @@ void KPrTextObject::recalcPageNum( KPrPage *page )
void KPrTextObject::tqlayout()
{
tqinvalidate();
- // Get the thing going though, tqrepainting doesn't call formatMore
+ // Get the thing going though, repainting doesn't call formatMore
m_textobj->formatMore( 2 );
}
@@ -1441,7 +1441,7 @@ void KPrTextObject::slotAvailableHeightNeeded()
void KPrTextObject::slotRepaintChanged()
{
- emit tqrepaintChanged( this );
+ emit repaintChanged( this );
}
KPrTextView * KPrTextObject::createKPTextView( KPrCanvas * _canvas, bool temp )
@@ -1518,7 +1518,7 @@ KCommand * KPrTextObject::pasteOasis( KoTextCursor * cursor, const TQByteArray &
*cursor = *( cmd->execute( cursor ) );
m_textobj->formatMore( 2 );
- emit tqrepaintChanged( this );
+ emit repaintChanged( this );
m_textobj->emitEnsureCursorVisible();
m_textobj->emitUpdateUI( true );
m_textobj->emitShowCursor();